pub struct Geolocator { /* private fields */ }Implementations
Sourceimpl Geolocator
impl Geolocator
pub fn name(&self) -> Cow<'static, str>
pub fn rate_limit_interval(&self) -> Duration
Sourcepub async fn find_ip_location(
&self,
client: &Client,
interval: Duration,
) -> Result<IPAddressInfo>
pub async fn find_ip_location( &self, client: &Client, interval: Duration, ) -> Result<IPAddressInfo>
No-op if last API call was made in the last interval seconds.
Transient errors are retried with exponential backoff, so callers
don’t need their own retry logic. If the service reported rate
limiting less than rate_limit_interval seconds ago, no request is
made and an error with a RateLimited cause is returned, so that
all callers collectively respect the limit.